
# Slot: genome build


The version of the genome on which a feature is located. For example, GRCh38 for Homo sapiens.

URI: [biolink:genome_build](https://w3id.org/biolink/vocab/genome_build)


## Domain and Range

[GenomicSequenceLocalization](GenomicSequenceLocalization.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [sequence localization attribute](sequence_localization_attribute.md)

## Children


## Used by

 * [GenomicSequenceLocalization](GenomicSequenceLocalization.md)
